{*****************************************}
{* Main unit for LogicGates7 application *}
{*****************************************}

// Implementation of the interactive graphics:
//   - the circuit layout is made of a mixture of shapes and images
//   - the LEDs are colored ellipses; different color styles are used for on/off status
//   - the movement of the switches is done by changing the vertical position (TOP property) of the corresponding shapes
//   - the switch shapes being very small and difficult to click by the user, I used a transperant image, placed over them;
//     the OnClick event of the image is used to trigger the actions to be done when the corresponding switch has been clicked.

unit binmult;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, Menus, StdCtrls, ExtCtrls, binmult22, binmult42, binmult43, common;

type
  {***********}
  { TfBinMult }
  {***********}
  TfBinMult = class(TForm)
    mMenu: TMainMenu;
    mFile, mFileExit: TMenuItem;
    mHelp, mHelpAbout: TMenuItem;
    StaticText1: TStaticText;
    Memo1, Memo2, Memo3, Memo4: TMemo;
    btBinMult22: TButton;
    btBinMult42: TButton;
    btBinMult43: TButton;
    procedure mFileExitClick(Sender: TObject);
    procedure mHelpAboutClick(Sender: TObject);
    procedure btBinMult22Click(Sender: TObject);
    procedure btBinMult42Click(Sender: TObject);
    procedure btBinMult43Click(Sender: TObject);
  end;

var
  fBinMult: TfBinMult;

implementation

{$R *.lfm}

{***********}
{ TfBinMult }
{***********}

{ Menu item "File > Exit": Exit application }

procedure TfBinMult.mFileExitClick(Sender: TObject);

begin
  Close;
end;

{ Menu item "Help > About": Display application about }

procedure TfBinMult.mHelpAboutClick(Sender: TObject);

var
  S: string;

begin
  S := 'Electronics simulation.' + LineEnding;
  S += 'Using logic gates to make binary multiplier circuits.' + LineEnding + LineEnding;
  S += 'Version 1.0, © allu, December 2020 - January 2021.';
  MessageDlg('About "LogicGates7"', S, mtInformation, [mbOK], 0);
end;

{ Button "2x2-bits multiplier": Open 2x2-bits multiplier simulation window }

procedure TfBinMult.btBinMult22Click(Sender: TObject);

begin
  fBinMult22.ShowModal;
end;

{ Button "4x2-bits multiplier": Open 4x2-bits multiplier simulation window }

procedure TfBinMult.btBinMult42Click(Sender: TObject);

begin
  fBinMult42.ShowModal;
end;

{ Button "4x3-bits multiplier": Open 4x3-bits multiplier simulation window }

procedure TfBinMult.btBinMult43Click(Sender: TObject);

begin
  fBinMult43.ShowModal;
end;

end.

